@@ -1,14 +1,13 @@
 #' Create and plot diffusion maps
-#' 
+#'
 #' The main function is \code{\link{DiffusionMap}}, which returns an object you can \code{\link{plot}} (\code{\link{plot.DiffusionMap}} is then called).
-#' 
+#'
 #' @examples
 #' demo(destiny, ask = FALSE)
-#' 
-#' @docType package
+#'
 #' @name destiny
-#' 
+#'
 ## Make sure Rcpp and RcppEigen are loaded
 #' @importFrom Rcpp evalCpp
 #' @importFrom RcppEigen RcppEigen.package.skeleton
-NULL
+'_PACKAGE'
