@@ -2,8 +2,8 @@ library(destiny)
 
 data(guo)
 
-Dark2 <- scales::brewer_pal(palette = 'Dark2')
-palette(Dark2(8L))
+dark2 <- scales::brewer_pal(palette = 'Dark2')
+palette(dark2(8L))
 
 
 
@@ -31,9 +31,3 @@ dm_guo_global <- DiffusionMap(guo, sigmas, verbose = FALSE,
                               censor_val = 10, censor_range = c(10, 40))
 plot(dm_guo_global,
      col = guo$num_cells, pch = 20)
-
-
-
-
-#library(rgl)
-#plot3d(eigenvectors(dm_guo)[, 1:3], col = guo$num_cells)
